/**
 * Copyright Copyright 2010 Simon Andrews
 *
 *    This file is part of Difference Tracker.
 *
 *    Difference Tracker is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    Difference Tracker is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with Difference Tracker; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.DifferenceTracker;

public class Particle {

	
	/**
	 * The particle class represents a single feature from a frame
	 * of the movie.  This feature will be built up from individual
	 * pixels 
	 */
	
	private int [][] keptPixels;
	private int pixelCount;
	private int totalX;
	private int totalY;
	
	public Particle (int width, int height, int x, int y) {
		keptPixels = new int [height][];
		keptPixels[y] = new int[2];
		keptPixels[y][0] = x;
		keptPixels[y][1] = x;
		totalX = x;
		totalY = y;
		pixelCount = 1;
	}
	
	public boolean wantsPixel (int x, int y) {
		
		for (int y1 = y-1;y1<=y+1 && y1 < keptPixels.length;y1++) {
			if (y1 < 0) continue;
			if (keptPixels[y1] == null) continue;

			if (x >= keptPixels[y1][0]-1 && x <= keptPixels[y1][1]+1) {
				// We're keeping it
				
//				System.out.println("New pixel "+x+","+y+" is close enough to "+keptPixels[y1][0]+"-"+keptPixels[y1][1]+","+y1);
				
				if (keptPixels[y] == null) {
					keptPixels[y] = new int[] {x,x};
				}
				else {
					if (x < keptPixels[y][0]) keptPixels[y][0] = x;
					else if (x > keptPixels[y][1]) keptPixels[y][1] = x;
				}
				++pixelCount;
				totalX += x;
				totalY += y;
//				System.out.println("Pixel count is now "+pixelCount);
				return true;
			}
		}
		
		return false;
	}
	
	public int volume () {
		int volume = 0;
		for (int y=0;y<keptPixels.length;y++) {
			if (keptPixels[y] != null) {
				volume += (1+(keptPixels[y][1]-keptPixels[y][0]));
			}
		}
		return volume;
	}
	
	public int pixelCount () {
		return pixelCount;
	}
	
	public XYPosition getCentrePosition () {
		return new XYPosition(totalX/pixelCount,totalY/pixelCount);
	}
}
