/**
 * Copyright Copyright 2010 Simon Andrews
 *
 *    This file is part of Difference Tracker.
 *
 *    Difference Tracker is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    Difference Tracker is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with Difference Tracker; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.DifferenceTracker;
import java.util.Enumeration;
import java.util.Vector;

import uk.ac.bbsrc.babraham.DifferenceTracker.Config.DifferenceTrackerPreferences;

import ij.process.ImageProcessor;


public class ParticleCollection {

	/**
	 * This class creates and stores a set of particles generated
	 * from a single frame of a movie.
	 */
	
	private int MIN_INTENSITY;
	
	Vector<Particle> particles = new Vector<Particle>();
	
	public ParticleCollection (ImageProcessor imp) {
		
		MIN_INTENSITY = DifferenceTrackerPreferences.getInstance().minTrackedIntensity();
		
		for (int w=0;w<imp.getWidth();w++) {
			PIXEL: for (int h=0;h<imp.getHeight();h++) {
				int pixel = imp.get(w, h);
				if (pixel <= MIN_INTENSITY) {
					continue;
				}
				
				Enumeration<Particle> e = particles.elements();
				while (e.hasMoreElements()) {
					if (e.nextElement().wantsPixel(w,h)) {
						// A pixel can only belong to one feature.
						continue PIXEL;
					}
				}
				
				// If we get here then none of the existing features
				// wants this pixel.
				Particle p = new Particle(imp.getWidth(),imp.getHeight(),w,h);
				particles.add(p);
				
//				System.out.println("Added new particle at "+w+","+h);
				
			}
		}
				
	}
	
	public Particle [] getAvailableParticles () {
		return particles.toArray(new Particle[0]);
	}
	
	public Particle [] getAvailableParticles (int minPixelCount) {
		Vector<Particle> keepers = new Vector<Particle>();
		Particle [] allParticles = getAvailableParticles();
		for (int p=0;p<allParticles.length;p++) {
			if (allParticles[p].pixelCount()>=minPixelCount) {
				keepers.add(allParticles[p]);
			}
		}
		
		return keepers.toArray(new Particle[0]);
	}
	
	public void removeParticle (Particle p) {
		
	}
}
