/**
 * Copyright Copyright 2010 Simon Andrews
 *
 *    This file is part of Difference Tracker.
 *
 *    Difference Tracker is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    Difference Tracker is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with Difference Tracker; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.DifferenceTracker.Results;

import ij.ImagePlus;

import java.text.DecimalFormat;

import javax.swing.table.AbstractTableModel;

import uk.ac.bbsrc.babraham.DifferenceTracker.ParticleSetStats;

public class TrackedResultsTableModel extends AbstractTableModel {
	
	private String fileName;
	private ParticleSetStats allParticles;
	private ParticleSetStats leftParticles;
	private ParticleSetStats rightParticles;
	private double area;
	
	private DecimalFormat doubleFormat = new DecimalFormat("#.###");
	
	
	private String [] headers = new String [] {	"File Name",
												"Total Track Count",
												"Average Particle Count Per Frame",
												"Average Particle Count Per Frame per 1000 px",
												"Average Track Duration",
												"Average Volume Per Particle",
												"Average Speed Per Track",
												"Average Max Speed Per Track",
												"[Left] Total Track Count",
												"[Left] Average Particle Count Per Frame",
												"[Left] Average Particle Count Per Frame per 1000 px",
												"[Left] Average Track Duration",
												"[Left] Average Volume Per Particle",
												"[Left] Average Speed Per Track",
												"[Left] Average Max Speed Per Track",
												"[Right] Total Track Count",
												"[Right] Average Particle Count Per Frame",
												"[Right] Average Particle Count Per Frame per 1000 px",
												"[Right] Average Track Duration",
												"[Right] Average Volume Per Particle",
												"[Right] Average Speed Per Track",
												"[Right] Average Max Speed Per Track"
	};
	
	
	
	public TrackedResultsTableModel (String fileName, ImagePlus imp, ParticleSetStats allParticles, ParticleSetStats leftParticles, ParticleSetStats rightParticles) {
		this.fileName = fileName;
		this.allParticles = allParticles;
		this.leftParticles = leftParticles;
		this.rightParticles = rightParticles;
		this.area = (imp.getWidth()*imp.getHeight())/1000d;
	}
	
	public int getColumnCount() {
		return 2;
	}
	
	public Class<?> getColumnClass (int columnIndex) {
		return String.class;
	}

	public int getRowCount() {
		return headers.length;
	}

	public Object getValueAt(int rowIndex, int columnIndex) {
		if (columnIndex == 0) {
			return headers[rowIndex];
		}
		else {
			switch (rowIndex) {
				case 0: return fileName;
				case 1: return new Integer(allParticles.totalCount);
				case 2: return doubleFormat.format(allParticles.averageCount);
				case 3: return doubleFormat.format(allParticles.averageCount/area);				
				case 4: return doubleFormat.format(allParticles.averageTrackDuration);
				case 5: return doubleFormat.format(allParticles.averageVolume);
				case 6: return doubleFormat.format(allParticles.averageSpeed);
				case 7: return doubleFormat.format(allParticles.averageMaxSpeed);
				case 8: return new Integer(leftParticles.totalCount);
				case 9: return doubleFormat.format(leftParticles.averageCount);
				case 10: return doubleFormat.format(leftParticles.averageCount/area);
				case 11: return doubleFormat.format(leftParticles.averageTrackDuration);
				case 12: return doubleFormat.format(leftParticles.averageVolume);
				case 13: return doubleFormat.format(leftParticles.averageSpeed);
				case 14: return doubleFormat.format(leftParticles.averageMaxSpeed);
				case 15: return new Integer(rightParticles.totalCount);
				case 16: return doubleFormat.format(rightParticles.averageCount);
				case 17: return doubleFormat.format(rightParticles.averageCount/area);
				case 18: return doubleFormat.format(rightParticles.averageTrackDuration);
				case 19: return doubleFormat.format(rightParticles.averageVolume);
				case 20: return doubleFormat.format(rightParticles.averageSpeed);
				case 21: return doubleFormat.format(rightParticles.averageMaxSpeed);
				default: return null;
			}
		}
	}	
	

}
